@@ -1,13 +1,22 @@
 # Django settings for testproj project.
 
+import os
+
 DEBUG = True
 TEMPLATE_DEBUG = DEBUG
 
 DATABASE_ENGINE = 'sqlite3'
 DATABASE_NAME = 'db'
 
+# FLASH_STORAGE = 'session'
+# FLASH_STORAGE = 'cookie'
+
 SECRET_KEY = 'g9b@q$)=^xd2g@-7pg=j=h3*8+xd#hgn-9je@iq5_m#seg&d1y'
 
+MEDIA_URL = '/media/'
+ADMIN_MEDIA_PREFIX = '/admin/'
+MEDIA_ROOT = os.path.normpath(os.path.dirname(__file__) + '/media/')
+
 TEMPLATE_LOADERS = (
     'django.template.loaders.filesystem.load_template_source',
 )
@@ -20,12 +29,11 @@ MIDDLEWARE_CLASSES = (
 
 TEMPLATE_CONTEXT_PROCESSORS = (
     'djangoflash.context_processors.flash',
+    'django.core.context_processors.media',
 )
 
 ROOT_URLCONF = 'testproj.urls'
 
-import os
-
 TEMPLATE_DIRS = (
     os.path.normpath(os.path.dirname(__file__) + '/templates'),
 )
